@@ -23,3 +23,9 @@ plot(r.sma, label.tol = 20, scale = "uvc",
 # change default of sub argument 
 plot(r.sma, label.tol = 20, scale = "uvc",
     col.group = (Golub.grp)[1:38], zoom = c(1,1.2), col.size = 5, sub = "")
+
+# omit sample names and add smooth scatter 
+plot(r.sma, label.tol = 20, scale = "uvc",
+    col.group = (Golub.grp)[1:38], zoom = c(1,1.2), col.size = 5, sub = "",
+    sampleNames = FALSE, do.smoothScatter = TRUE)
+
